{##
  This file contains a Jinja2 front-matter template that adds version and authorship information.
  Changing the Jinja2 templates in this file may cause incompatibility with Manubot updates.
  Pandoc automatically inserts title from metadata.yaml, so it is not included in this template.
##}

{## Uncomment & edit the following line to reference to a preprinted or published version of the manuscript.
_A DOI-citable version of this manuscript is available at <https://doi.org/DOI_HERE>_.
##}

<!-- {## Template to insert build date and source ##} -->
<div style="text-align:center">
<small><em>
This manuscript
{% if manubot.ci_source is defined and manubot.ci_source.provider == "appveyor" -%}
([permalink]({{manubot.ci_source.artifact_url}}))
{% elif manubot.html_url_versioned is defined -%}
([permalink]({{manubot.html_url_versioned}}))
{% endif -%}
was automatically generated
{% if manubot.ci_source is defined -%}
from [{{manubot.ci_source.repo_slug}}@{{manubot.ci_source.commit | truncate(length=7, end='', leeway=0)}}](https://github.com/{{manubot.ci_source.repo_slug}}/tree/{{manubot.ci_source.commit}})
{% endif -%}
on {{manubot.date}}. <br>View [non-interactive version on BioRxiv]({{biorxiv}}).
</em></small> 
</div>


<!-- {## Template for listing authors ##} -->
<!-- {% for author in manubot.authors %}
+ **{{author.name}}** {{author.symbol_str}} {% if author.correspondence is defined and author.correspondence == true -%}^[✉](#correspondence)^{%- endif -%} <br>
  {%- if author.orcid is defined and author.orcid is not none %}
    ![ORCID icon](images/orcid.svg){.inline_icon}
    [{{author.orcid}}](https://orcid.org/{{author.orcid}})
  {%- endif %}
  {%- if author.github is defined and author.github is not none %}
    · ![GitHub icon](images/github.svg){.inline_icon}
    [{{author.github}}](https://github.com/{{author.github}})
  {%- endif %}
  {%- if author.twitter is defined and author.twitter is not none %}
    · ![Twitter icon](images/twitter.svg){.inline_icon}
    [{{author.twitter}}](https://twitter.com/{{author.twitter}})
  {%- endif %}<br>
  <small>
  {%- if author.affiliations is defined and author.affiliations|length %}
     {{author.affiliations | join('; ')}}
  {%- endif %}
  {%- if author.funders is defined and author.funders|length %}
     · Funded by {{author.funders | join('; ')}}
  {%- endif %}
  </small>
{% endfor %} -->


{% for author in manubot.authors %}
{% if author.orcid is defined -%}
[![ORCID icon](images/orcid.svg){height="11px" width="11px"}](https://orcid.org/{{author.orcid}})
{%- endif %}
{{author.name}} <sup>{{author.affiliation_numbers | join(',')}}{%- if author.symbol_str is defined -%},{{author.symbol_str}}{%- endif -%}</sup>
{%- if not loop.last -%}, {%- endif -%}
{% endfor %}


<!--<sup>☯</sup> --- These authors contributed equally. <br> -->
<sup>✉</sup> --- To whom correspondence should be addressed: ursula.roethlisberger@epfl.ch
<small>

###### Affiliations
{% for affiliation in manubot.affiliations %}
{{affiliation.affiliation_number}}. {{affiliation.affiliation}}
{%- endfor %}


